@@ -1,13 +1,13 @@
-from typing import List
+from __future__ import annotations
 
 from subclean.core.line import Line
 from subclean.core.section.timing import SectionTiming, SrtSectionTiming
 
 
 class Section:
-    def __init__(self, timing: SectionTiming, lines: List[Line] = []):
+    def __init__(self, timing: SectionTiming, lines: list[Line] = []):
         self.timing: SectionTiming = timing
-        self.lines: List[Line] = lines
+        self.lines: list[Line] = lines
 
     def add_line(self, line: Line) -> None:
         self.lines.append(line)
@@ -30,18 +30,15 @@ class Section:
         return sum(len(line) for line in self.lines) == 0
 
     def content(self) -> str:
-        pass
+        return "\n".join(self.lines)
 
     def __len__(self) -> int:
         return len(self.lines)
 
 
 class SrtSection(Section):
-    def __init__(self, timing: SrtSectionTiming, lines: List[Line] = []):
+    def __init__(self, timing: SrtSectionTiming, lines: list[Line] = []):
         super().__init__(timing, lines)
 
-    def content(self) -> str:
-        return "\n".join(self.lines)
-
     def __str__(self) -> str:
         return f"{self.timing}\n{self.content()}\n"
